# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class ChainList(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    
    @schemas.classproperty
    def ETH(cls):
        return cls("eth")
    
    @schemas.classproperty
    def X1(cls):
        return cls("0x1")
    
    @schemas.classproperty
    def GOERLI(cls):
        return cls("goerli")
    
    @schemas.classproperty
    def X5(cls):
        return cls("0x5")
    
    @schemas.classproperty
    def SEPOLIA(cls):
        return cls("sepolia")
    
    @schemas.classproperty
    def XAA36A7(cls):
        return cls("0xaa36a7")
    
    @schemas.classproperty
    def POLYGON(cls):
        return cls("polygon")
    
    @schemas.classproperty
    def X89(cls):
        return cls("0x89")
    
    @schemas.classproperty
    def MUMBAI(cls):
        return cls("mumbai")
    
    @schemas.classproperty
    def X13881(cls):
        return cls("0x13881")
    
    @schemas.classproperty
    def BSC(cls):
        return cls("bsc")
    
    @schemas.classproperty
    def X38(cls):
        return cls("0x38")
    
    @schemas.classproperty
    def BSC_TESTNET(cls):
        return cls("bsc testnet")
    
    @schemas.classproperty
    def X61(cls):
        return cls("0x61")
    
    @schemas.classproperty
    def AVALANCHE(cls):
        return cls("avalanche")
    
    @schemas.classproperty
    def XA86A(cls):
        return cls("0xa86a")
    
    @schemas.classproperty
    def FANTOM(cls):
        return cls("fantom")
    
    @schemas.classproperty
    def XFA(cls):
        return cls("0xfa")
    
    @schemas.classproperty
    def PALM(cls):
        return cls("palm")
    
    @schemas.classproperty
    def X2A15C308D(cls):
        return cls("0x2a15c308d")
    
    @schemas.classproperty
    def CRONOS(cls):
        return cls("cronos")
    
    @schemas.classproperty
    def X19(cls):
        return cls("0x19")
    
    @schemas.classproperty
    def ARBITRUM(cls):
        return cls("arbitrum")
    
    @schemas.classproperty
    def XA4B1(cls):
        return cls("0xa4b1")
    
    @schemas.classproperty
    def CHILIZ(cls):
        return cls("chiliz")
    
    @schemas.classproperty
    def X15B38(cls):
        return cls("0x15b38")
    
    @schemas.classproperty
    def CHILIZ_TESTNET(cls):
        return cls("chiliz testnet")
    
    @schemas.classproperty
    def X15B32(cls):
        return cls("0x15b32")
    
    @schemas.classproperty
    def GNOSIS(cls):
        return cls("gnosis")
    
    @schemas.classproperty
    def X64(cls):
        return cls("0x64")
    
    @schemas.classproperty
    def GNOSIS_TESTNET(cls):
        return cls("gnosis testnet")
    
    @schemas.classproperty
    def X27D8(cls):
        return cls("0x27d8")
    
    @schemas.classproperty
    def BASE(cls):
        return cls("base")
    
    @schemas.classproperty
    def X2105(cls):
        return cls("0x2105")
    
    @schemas.classproperty
    def BASE_TESTNET(cls):
        return cls("base testnet")
    
    @schemas.classproperty
    def X14A33(cls):
        return cls("0x14a33")
    
    @schemas.classproperty
    def OPTIMISM(cls):
        return cls("optimism")
    
    @schemas.classproperty
    def XA(cls):
        return cls("0xa")



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class MarketDataERC20TokensByPriceMovers(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "gainers",
            "losers",
        }
        
        class properties:
        
            @staticmethod
            def gainers() -> typing.Type['MarketDataERC20Token']:
                return MarketDataERC20Token
        
            @staticmethod
            def losers() -> typing.Type['MarketDataERC20Token']:
                return MarketDataERC20Token
            __annotations__ = {
                "gainers": gainers,
                "losers": losers,
            }
    
    gainers: 'MarketDataERC20Token'
    losers: 'MarketDataERC20Token'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gainers"]) -> 'MarketDataERC20Token': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["losers"]) -> 'MarketDataERC20Token': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["gainers", "losers", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gainers"]) -> 'MarketDataERC20Token': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["losers"]) -> 'MarketDataERC20Token': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["gainers", "losers", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        gainers: 'MarketDataERC20Token',
        losers: 'MarketDataERC20Token',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'MarketDataERC20TokensByPriceMovers':
        return super().__new__(
            cls,
            *args,
            gainers=gainers,
            losers=losers,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.market_data_erc20_token import MarketDataERC20Token



from .balance import balance
from .block import block
from .defi import defi
from .events import events
from .ipfs import ipfs
from .market_data import market_data
from .nft import nft
from .resolve import resolve
from .token import token
from .transaction import transaction
from .utils import utils
from .wallets import wallets



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class DiscoveryToken(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class items(
            schemas.AnyTypeSchema,
        ):
        
        
            class MetaOapg:
                required = {
                    "price_usd",
                    "total_number_of_rating",
                    "experienced_net_buyers_change",
                    "chain_id",
                    "fully_diluted_valuation",
                    "rating",
                    "block_number",
                    "token_address",
                    "total_liquidity_locked_in_percent",
                    "net_volume_change_usd",
                    "twitter_followers",
                    "market_cap",
                    "volume_change_usd",
                    "block_timestamp",
                    "security_score",
                    "token_logo",
                    "token_name",
                    "total_supply_locked_in_percent",
                    "holders_change",
                    "links",
                    "price_percent_change_usd",
                    "token_symbol",
                    "liquidity_change_usd",
                }
                
                class properties:
                    chain_id = schemas.StrSchema
                    token_address = schemas.StrSchema
                    
                    
                    class token_name(
                        schemas.StrBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneStrMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, str, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'token_name':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class token_symbol(
                        schemas.StrBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneStrMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, str, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'token_symbol':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class token_logo(
                        schemas.StrBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneStrMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, str, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'token_logo':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class block_number(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'block_number':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class block_timestamp(
                        schemas.StrBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneStrMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, str, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'block_timestamp':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                
                    @staticmethod
                    def links() -> typing.Type['DiscoveryTokenLinks']:
                        return DiscoveryTokenLinks
                    
                    
                    class rating(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'rating':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class total_number_of_rating(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'total_number_of_rating':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class total_liquidity_locked_in_percent(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'total_liquidity_locked_in_percent':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class total_supply_locked_in_percent(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'total_supply_locked_in_percent':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class price_usd(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'price_usd':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class security_score(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'security_score':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class market_cap(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'market_cap':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class fully_diluted_valuation(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'fully_diluted_valuation':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                    
                    
                    class twitter_followers(
                        schemas.NumberBase,
                        schemas.NoneBase,
                        schemas.Schema,
                        schemas.NoneDecimalMixin
                    ):
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[None, decimal.Decimal, int, float, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'twitter_followers':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                            )
                
                    @staticmethod
                    def holders_change() -> typing.Type['TimeFrames']:
                        return TimeFrames
                
                    @staticmethod
                    def liquidity_change_usd() -> typing.Type['TimeFrames']:
                        return TimeFrames
                
                    @staticmethod
                    def experienced_net_buyers_change() -> typing.Type['TimeFrames']:
                        return TimeFrames
                
                    @staticmethod
                    def volume_change_usd() -> typing.Type['TimeFrames']:
                        return TimeFrames
                
                    @staticmethod
                    def net_volume_change_usd() -> typing.Type['TimeFrames']:
                        return TimeFrames
                
                    @staticmethod
                    def price_percent_change_usd() -> typing.Type['TimeFrames']:
                        return TimeFrames
                    __annotations__ = {
                        "chain_id": chain_id,
                        "token_address": token_address,
                        "token_name": token_name,
                        "token_symbol": token_symbol,
                        "token_logo": token_logo,
                        "block_number": block_number,
                        "block_timestamp": block_timestamp,
                        "links": links,
                        "rating": rating,
                        "total_number_of_rating": total_number_of_rating,
                        "total_liquidity_locked_in_percent": total_liquidity_locked_in_percent,
                        "total_supply_locked_in_percent": total_supply_locked_in_percent,
                        "price_usd": price_usd,
                        "security_score": security_score,
                        "market_cap": market_cap,
                        "fully_diluted_valuation": fully_diluted_valuation,
                        "twitter_followers": twitter_followers,
                        "holders_change": holders_change,
                        "liquidity_change_usd": liquidity_change_usd,
                        "experienced_net_buyers_change": experienced_net_buyers_change,
                        "volume_change_usd": volume_change_usd,
                        "net_volume_change_usd": net_volume_change_usd,
                        "price_percent_change_usd": price_percent_change_usd,
                    }
        
            
            price_usd: MetaOapg.properties.price_usd
            total_number_of_rating: MetaOapg.properties.total_number_of_rating
            experienced_net_buyers_change: 'TimeFrames'
            chain_id: MetaOapg.properties.chain_id
            fully_diluted_valuation: MetaOapg.properties.fully_diluted_valuation
            rating: MetaOapg.properties.rating
            block_number: MetaOapg.properties.block_number
            token_address: MetaOapg.properties.token_address
            total_liquidity_locked_in_percent: MetaOapg.properties.total_liquidity_locked_in_percent
            net_volume_change_usd: 'TimeFrames'
            twitter_followers: MetaOapg.properties.twitter_followers
            market_cap: MetaOapg.properties.market_cap
            volume_change_usd: 'TimeFrames'
            block_timestamp: MetaOapg.properties.block_timestamp
            security_score: MetaOapg.properties.security_score
            token_logo: MetaOapg.properties.token_logo
            token_name: MetaOapg.properties.token_name
            total_supply_locked_in_percent: MetaOapg.properties.total_supply_locked_in_percent
            holders_change: 'TimeFrames'
            links: 'DiscoveryTokenLinks'
            price_percent_change_usd: 'TimeFrames'
            token_symbol: MetaOapg.properties.token_symbol
            liquidity_change_usd: 'TimeFrames'
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_name"]) -> MetaOapg.properties.token_name: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_symbol"]) -> MetaOapg.properties.token_symbol: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_logo"]) -> MetaOapg.properties.token_logo: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["links"]) -> 'DiscoveryTokenLinks': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["rating"]) -> MetaOapg.properties.rating: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["total_number_of_rating"]) -> MetaOapg.properties.total_number_of_rating: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["total_liquidity_locked_in_percent"]) -> MetaOapg.properties.total_liquidity_locked_in_percent: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["total_supply_locked_in_percent"]) -> MetaOapg.properties.total_supply_locked_in_percent: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["security_score"]) -> MetaOapg.properties.security_score: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["market_cap"]) -> MetaOapg.properties.market_cap: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["fully_diluted_valuation"]) -> MetaOapg.properties.fully_diluted_valuation: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["twitter_followers"]) -> MetaOapg.properties.twitter_followers: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["holders_change"]) -> 'TimeFrames': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["liquidity_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["experienced_net_buyers_change"]) -> 'TimeFrames': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["volume_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["net_volume_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["price_percent_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["chain_id", "token_address", "token_name", "token_symbol", "token_logo", "block_number", "block_timestamp", "links", "rating", "total_number_of_rating", "total_liquidity_locked_in_percent", "total_supply_locked_in_percent", "price_usd", "security_score", "market_cap", "fully_diluted_valuation", "twitter_followers", "holders_change", "liquidity_change_usd", "experienced_net_buyers_change", "volume_change_usd", "net_volume_change_usd", "price_percent_change_usd", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_name"]) -> MetaOapg.properties.token_name: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_symbol"]) -> MetaOapg.properties.token_symbol: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_logo"]) -> MetaOapg.properties.token_logo: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["links"]) -> 'DiscoveryTokenLinks': ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["rating"]) -> MetaOapg.properties.rating: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["total_number_of_rating"]) -> MetaOapg.properties.total_number_of_rating: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["total_liquidity_locked_in_percent"]) -> MetaOapg.properties.total_liquidity_locked_in_percent: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["total_supply_locked_in_percent"]) -> MetaOapg.properties.total_supply_locked_in_percent: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["security_score"]) -> MetaOapg.properties.security_score: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["market_cap"]) -> MetaOapg.properties.market_cap: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["fully_diluted_valuation"]) -> MetaOapg.properties.fully_diluted_valuation: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["twitter_followers"]) -> MetaOapg.properties.twitter_followers: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["holders_change"]) -> 'TimeFrames': ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["liquidity_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["experienced_net_buyers_change"]) -> 'TimeFrames': ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["volume_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["net_volume_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["price_percent_change_usd"]) -> 'TimeFrames': ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["chain_id", "token_address", "token_name", "token_symbol", "token_logo", "block_number", "block_timestamp", "links", "rating", "total_number_of_rating", "total_liquidity_locked_in_percent", "total_supply_locked_in_percent", "price_usd", "security_score", "market_cap", "fully_diluted_valuation", "twitter_followers", "holders_change", "liquidity_change_usd", "experienced_net_buyers_change", "volume_change_usd", "net_volume_change_usd", "price_percent_change_usd", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                price_usd: typing.Union[MetaOapg.properties.price_usd, None, decimal.Decimal, int, float, ],
                total_number_of_rating: typing.Union[MetaOapg.properties.total_number_of_rating, None, decimal.Decimal, int, float, ],
                experienced_net_buyers_change: 'TimeFrames',
                chain_id: typing.Union[MetaOapg.properties.chain_id, str, ],
                fully_diluted_valuation: typing.Union[MetaOapg.properties.fully_diluted_valuation, None, decimal.Decimal, int, float, ],
                rating: typing.Union[MetaOapg.properties.rating, None, decimal.Decimal, int, float, ],
                block_number: typing.Union[MetaOapg.properties.block_number, None, decimal.Decimal, int, float, ],
                token_address: typing.Union[MetaOapg.properties.token_address, str, ],
                total_liquidity_locked_in_percent: typing.Union[MetaOapg.properties.total_liquidity_locked_in_percent, None, decimal.Decimal, int, float, ],
                net_volume_change_usd: 'TimeFrames',
                twitter_followers: typing.Union[MetaOapg.properties.twitter_followers, None, decimal.Decimal, int, float, ],
                market_cap: typing.Union[MetaOapg.properties.market_cap, None, decimal.Decimal, int, float, ],
                volume_change_usd: 'TimeFrames',
                block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, None, str, ],
                security_score: typing.Union[MetaOapg.properties.security_score, None, decimal.Decimal, int, float, ],
                token_logo: typing.Union[MetaOapg.properties.token_logo, None, str, ],
                token_name: typing.Union[MetaOapg.properties.token_name, None, str, ],
                total_supply_locked_in_percent: typing.Union[MetaOapg.properties.total_supply_locked_in_percent, None, decimal.Decimal, int, float, ],
                holders_change: 'TimeFrames',
                links: 'DiscoveryTokenLinks',
                price_percent_change_usd: 'TimeFrames',
                token_symbol: typing.Union[MetaOapg.properties.token_symbol, None, str, ],
                liquidity_change_usd: 'TimeFrames',
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *args,
                    price_usd=price_usd,
                    total_number_of_rating=total_number_of_rating,
                    experienced_net_buyers_change=experienced_net_buyers_change,
                    chain_id=chain_id,
                    fully_diluted_valuation=fully_diluted_valuation,
                    rating=rating,
                    block_number=block_number,
                    token_address=token_address,
                    total_liquidity_locked_in_percent=total_liquidity_locked_in_percent,
                    net_volume_change_usd=net_volume_change_usd,
                    twitter_followers=twitter_followers,
                    market_cap=market_cap,
                    volume_change_usd=volume_change_usd,
                    block_timestamp=block_timestamp,
                    security_score=security_score,
                    token_logo=token_logo,
                    token_name=token_name,
                    total_supply_locked_in_percent=total_supply_locked_in_percent,
                    holders_change=holders_change,
                    links=links,
                    price_percent_change_usd=price_percent_change_usd,
                    token_symbol=token_symbol,
                    liquidity_change_usd=liquidity_change_usd,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'DiscoveryToken':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)

from openapi_evm_api.model.discovery_token_links import DiscoveryTokenLinks
from openapi_evm_api.model.time_frames import TimeFrames



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class MarketDataHottestNFTCollectionByTradingVolume(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class items(
            schemas.AnyTypeSchema,
        ):
        
        
            class MetaOapg:
                required = {
                    "collection_image",
                    "floor_price_usd",
                    "collection_title",
                    "market_cap_24hr_percent_change",
                    "volume_24hr_percent_change",
                    "rank",
                    "volume_usd",
                    "market_cap_usd",
                    "floor_price_24hr_percent_change",
                }
                
                class properties:
                    rank = schemas.IntSchema
                    collection_title = schemas.StrSchema
                    collection_image = schemas.StrSchema
                    floor_price_usd = schemas.StrSchema
                    floor_price_24hr_percent_change = schemas.StrSchema
                    volume_usd = schemas.StrSchema
                    volume_24hr_percent_change = schemas.StrSchema
                    average_price_usd = schemas.StrSchema
                    __annotations__ = {
                        "rank": rank,
                        "collection_title": collection_title,
                        "collection_image": collection_image,
                        "floor_price_usd": floor_price_usd,
                        "floor_price_24hr_percent_change": floor_price_24hr_percent_change,
                        "volume_usd": volume_usd,
                        "volume_24hr_percent_change": volume_24hr_percent_change,
                        "average_price_usd": average_price_usd,
                    }
        
            
            collection_image: MetaOapg.properties.collection_image
            floor_price_usd: MetaOapg.properties.floor_price_usd
            collection_title: MetaOapg.properties.collection_title
            market_cap_24hr_percent_change: schemas.AnyTypeSchema
            volume_24hr_percent_change: MetaOapg.properties.volume_24hr_percent_change
            rank: MetaOapg.properties.rank
            volume_usd: MetaOapg.properties.volume_usd
            market_cap_usd: schemas.AnyTypeSchema
            floor_price_24hr_percent_change: MetaOapg.properties.floor_price_24hr_percent_change
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["rank"]) -> MetaOapg.properties.rank: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["collection_title"]) -> MetaOapg.properties.collection_title: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["collection_image"]) -> MetaOapg.properties.collection_image: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["floor_price_usd"]) -> MetaOapg.properties.floor_price_usd: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["floor_price_24hr_percent_change"]) -> MetaOapg.properties.floor_price_24hr_percent_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["volume_usd"]) -> MetaOapg.properties.volume_usd: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["volume_24hr_percent_change"]) -> MetaOapg.properties.volume_24hr_percent_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["average_price_usd"]) -> MetaOapg.properties.average_price_usd: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["rank", "collection_title", "collection_image", "floor_price_usd", "floor_price_24hr_percent_change", "volume_usd", "volume_24hr_percent_change", "average_price_usd", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["rank"]) -> MetaOapg.properties.rank: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["collection_title"]) -> MetaOapg.properties.collection_title: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["collection_image"]) -> MetaOapg.properties.collection_image: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["floor_price_usd"]) -> MetaOapg.properties.floor_price_usd: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["floor_price_24hr_percent_change"]) -> MetaOapg.properties.floor_price_24hr_percent_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["volume_usd"]) -> MetaOapg.properties.volume_usd: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["volume_24hr_percent_change"]) -> MetaOapg.properties.volume_24hr_percent_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["average_price_usd"]) -> typing.Union[MetaOapg.properties.average_price_usd, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["rank", "collection_title", "collection_image", "floor_price_usd", "floor_price_24hr_percent_change", "volume_usd", "volume_24hr_percent_change", "average_price_usd", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                collection_image: typing.Union[MetaOapg.properties.collection_image, str, ],
                floor_price_usd: typing.Union[MetaOapg.properties.floor_price_usd, str, ],
                collection_title: typing.Union[MetaOapg.properties.collection_title, str, ],
                market_cap_24hr_percent_change: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                volume_24hr_percent_change: typing.Union[MetaOapg.properties.volume_24hr_percent_change, str, ],
                rank: typing.Union[MetaOapg.properties.rank, decimal.Decimal, int, ],
                volume_usd: typing.Union[MetaOapg.properties.volume_usd, str, ],
                market_cap_usd: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                floor_price_24hr_percent_change: typing.Union[MetaOapg.properties.floor_price_24hr_percent_change, str, ],
                average_price_usd: typing.Union[MetaOapg.properties.average_price_usd, str, schemas.Unset] = schemas.unset,
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *args,
                    collection_image=collection_image,
                    floor_price_usd=floor_price_usd,
                    collection_title=collection_title,
                    market_cap_24hr_percent_change=market_cap_24hr_percent_change,
                    volume_24hr_percent_change=volume_24hr_percent_change,
                    rank=rank,
                    volume_usd=volume_usd,
                    market_cap_usd=market_cap_usd,
                    floor_price_24hr_percent_change=floor_price_24hr_percent_change,
                    average_price_usd=average_price_usd,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'MarketDataHottestNFTCollectionByTradingVolume':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Erc20Price(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "usdPrice",
        }
        
        class properties:
            usdPrice = schemas.Float64Schema
            tokenName = schemas.StrSchema
            tokenSymbol = schemas.StrSchema
            tokenLogo = schemas.StrSchema
            tokenDecimals = schemas.StrSchema
        
            @staticmethod
            def nativePrice() -> typing.Type['NativeErc20Price']:
                return NativeErc20Price
            usdPriceFormatted = schemas.StrSchema
            _24hr_percent_change = schemas.StrSchema
            exchangeAddress = schemas.StrSchema
            exchangeName = schemas.StrSchema
            tokenAddress = schemas.StrSchema
            toBlock = schemas.StrSchema
            __annotations__ = {
                "usdPrice": usdPrice,
                "tokenName": tokenName,
                "tokenSymbol": tokenSymbol,
                "tokenLogo": tokenLogo,
                "tokenDecimals": tokenDecimals,
                "nativePrice": nativePrice,
                "usdPriceFormatted": usdPriceFormatted,
                "24hrPercentChange": _24hr_percent_change,
                "exchangeAddress": exchangeAddress,
                "exchangeName": exchangeName,
                "tokenAddress": tokenAddress,
                "toBlock": toBlock,
            }

    
    usdPrice: MetaOapg.properties.usdPrice
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usdPrice"]) -> MetaOapg.properties.usdPrice: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tokenName"]) -> MetaOapg.properties.tokenName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tokenSymbol"]) -> MetaOapg.properties.tokenSymbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tokenLogo"]) -> MetaOapg.properties.tokenLogo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tokenDecimals"]) -> MetaOapg.properties.tokenDecimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nativePrice"]) -> 'NativeErc20Price': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usdPriceFormatted"]) -> MetaOapg.properties.usdPriceFormatted: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["24hrPercentChange"]) -> MetaOapg.properties._24hr_percent_change: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exchangeAddress"]) -> MetaOapg.properties.exchangeAddress: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exchangeName"]) -> MetaOapg.properties.exchangeName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tokenAddress"]) -> MetaOapg.properties.tokenAddress: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["toBlock"]) -> MetaOapg.properties.toBlock: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["usdPrice", "tokenName", "tokenSymbol", "tokenLogo", "tokenDecimals", "nativePrice", "usdPriceFormatted", "24hrPercentChange", "exchangeAddress", "exchangeName", "tokenAddress", "toBlock", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usdPrice"]) -> MetaOapg.properties.usdPrice: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tokenName"]) -> typing.Union[MetaOapg.properties.tokenName, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tokenSymbol"]) -> typing.Union[MetaOapg.properties.tokenSymbol, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tokenLogo"]) -> typing.Union[MetaOapg.properties.tokenLogo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tokenDecimals"]) -> typing.Union[MetaOapg.properties.tokenDecimals, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nativePrice"]) -> typing.Union['NativeErc20Price', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usdPriceFormatted"]) -> typing.Union[MetaOapg.properties.usdPriceFormatted, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["24hrPercentChange"]) -> typing.Union[MetaOapg.properties._24hr_percent_change, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exchangeAddress"]) -> typing.Union[MetaOapg.properties.exchangeAddress, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exchangeName"]) -> typing.Union[MetaOapg.properties.exchangeName, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tokenAddress"]) -> typing.Union[MetaOapg.properties.tokenAddress, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["toBlock"]) -> typing.Union[MetaOapg.properties.toBlock, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["usdPrice", "tokenName", "tokenSymbol", "tokenLogo", "tokenDecimals", "nativePrice", "usdPriceFormatted", "24hrPercentChange", "exchangeAddress", "exchangeName", "tokenAddress", "toBlock", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        usdPrice: typing.Union[MetaOapg.properties.usdPrice, decimal.Decimal, int, float, ],
        tokenName: typing.Union[MetaOapg.properties.tokenName, str, schemas.Unset] = schemas.unset,
        tokenSymbol: typing.Union[MetaOapg.properties.tokenSymbol, str, schemas.Unset] = schemas.unset,
        tokenLogo: typing.Union[MetaOapg.properties.tokenLogo, str, schemas.Unset] = schemas.unset,
        tokenDecimals: typing.Union[MetaOapg.properties.tokenDecimals, str, schemas.Unset] = schemas.unset,
        nativePrice: typing.Union['NativeErc20Price', schemas.Unset] = schemas.unset,
        usdPriceFormatted: typing.Union[MetaOapg.properties.usdPriceFormatted, str, schemas.Unset] = schemas.unset,
        exchangeAddress: typing.Union[MetaOapg.properties.exchangeAddress, str, schemas.Unset] = schemas.unset,
        exchangeName: typing.Union[MetaOapg.properties.exchangeName, str, schemas.Unset] = schemas.unset,
        tokenAddress: typing.Union[MetaOapg.properties.tokenAddress, str, schemas.Unset] = schemas.unset,
        toBlock: typing.Union[MetaOapg.properties.toBlock, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Erc20Price':
        return super().__new__(
            cls,
            *args,
            usdPrice=usdPrice,
            tokenName=tokenName,
            tokenSymbol=tokenSymbol,
            tokenLogo=tokenLogo,
            tokenDecimals=tokenDecimals,
            nativePrice=nativePrice,
            usdPriceFormatted=usdPriceFormatted,
            exchangeAddress=exchangeAddress,
            exchangeName=exchangeName,
            tokenAddress=tokenAddress,
            toBlock=toBlock,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.native_erc20_price import NativeErc20Price



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.market_data_nfts_hottest_collections.get import GetHottestNftCollectionsByTradingVolume
from openapi_evm_api.paths.market_data_erc20s_top_tokens.get import GetTopErc20TokensByMarketCap
from openapi_evm_api.paths.market_data_erc20s_top_movers.get import GetTopErc20TokensByPriceMovers
from openapi_evm_api.paths.market_data_nfts_top_collections.get import GetTopNftCollectionsByMarketCap


class MarketDataApi(
    GetHottestNftCollectionsByTradingVolume,
    GetTopErc20TokensByMarketCap,
    GetTopErc20TokensByPriceMovers,
    GetTopNftCollectionsByMarketCap,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class ContractsReviewItem(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "contract_type",
            "reason",
            "report_type",
            "contract_address",
        }
        
        class properties:
            contract_address = schemas.StrSchema
            reason = schemas.StrSchema
            
            
            class report_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def SPAM(cls):
                    return cls("spam")
                
                @schemas.classproperty
                def NOT_SPAM(cls):
                    return cls("not_spam")
            
            
            class contract_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def ERC20(cls):
                    return cls("ERC20")
                
                @schemas.classproperty
                def NFT(cls):
                    return cls("NFT")
            __annotations__ = {
                "contract_address": contract_address,
                "reason": reason,
                "report_type": report_type,
                "contract_type": contract_type,
            }

    
    contract_type: MetaOapg.properties.contract_type
    reason: MetaOapg.properties.reason
    report_type: MetaOapg.properties.report_type
    contract_address: MetaOapg.properties.contract_address
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["contract_address"]) -> MetaOapg.properties.contract_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["report_type"]) -> MetaOapg.properties.report_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["contract_type"]) -> MetaOapg.properties.contract_type: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["contract_address", "reason", "report_type", "contract_type", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["contract_address"]) -> MetaOapg.properties.contract_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["report_type"]) -> MetaOapg.properties.report_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["contract_type"]) -> MetaOapg.properties.contract_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["contract_address", "reason", "report_type", "contract_type", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        contract_type: typing.Union[MetaOapg.properties.contract_type, str, ],
        reason: typing.Union[MetaOapg.properties.reason, str, ],
        report_type: typing.Union[MetaOapg.properties.report_type, str, ],
        contract_address: typing.Union[MetaOapg.properties.contract_address, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ContractsReviewItem':
        return super().__new__(
            cls,
            *args,
            contract_type=contract_type,
            reason=reason,
            report_type=report_type,
            contract_address=contract_address,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class TokenItem(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            token_address = schemas.StrSchema
            token_id = schemas.StrSchema
            __annotations__ = {
                "token_address": token_address,
                "token_id": token_id,
            }

    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_id"]) -> MetaOapg.properties.token_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["token_address", "token_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_address"]) -> typing.Union[MetaOapg.properties.token_address, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_id"]) -> typing.Union[MetaOapg.properties.token_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["token_address", "token_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        token_address: typing.Union[MetaOapg.properties.token_address, str, schemas.Unset] = schemas.unset,
        token_id: typing.Union[MetaOapg.properties.token_id, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TokenItem':
        return super().__new__(
            cls,
            *args,
            token_address=token_address,
            token_id=token_id,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.resolve_address_reverse.get import ResolveAddress
from openapi_evm_api.paths.resolve_address_domain.get import ResolveAddressToDomain
from openapi_evm_api.paths.resolve_domain.get import ResolveDomain
from openapi_evm_api.paths.resolve_ens_domain.get import ResolveEnsDomain


class ResolveApi(
    ResolveAddress,
    ResolveAddressToDomain,
    ResolveDomain,
    ResolveEnsDomain,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_evm_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_evm_api.model.block import Block
from openapi_evm_api.model.block_date import BlockDate
from openapi_evm_api.model.block_token_stat import BlockTokenStat
from openapi_evm_api.model.block_transaction import BlockTransaction
from openapi_evm_api.model.block_transaction_decoded import BlockTransactionDecoded
from openapi_evm_api.model.block_transaction_verbose import BlockTransactionVerbose
from openapi_evm_api.model.chain_list import ChainList
from openapi_evm_api.model.contracts_review_dto import ContractsReviewDto
from openapi_evm_api.model.contracts_review_item import ContractsReviewItem
from openapi_evm_api.model.decoded_call import DecodedCall
from openapi_evm_api.model.decoded_event import DecodedEvent
from openapi_evm_api.model.discovery_api_chains_list import DiscoveryApiChainsList
from openapi_evm_api.model.discovery_token import DiscoveryToken
from openapi_evm_api.model.discovery_token_links import DiscoveryTokenLinks
from openapi_evm_api.model.discovery_tokens import DiscoveryTokens
from openapi_evm_api.model.endpoint_weights import EndpointWeights
from openapi_evm_api.model.ens import Ens
from openapi_evm_api.model.erc20_allowance import Erc20Allowance
from openapi_evm_api.model.erc20_metadata import Erc20Metadata
from openapi_evm_api.model.erc20_price import Erc20Price
from openapi_evm_api.model.erc20_token_balance import Erc20TokenBalance
from openapi_evm_api.model.erc20_token_stat import Erc20TokenStat
from openapi_evm_api.model.erc20_transaction import Erc20Transaction
from openapi_evm_api.model.erc20_transaction_collection import Erc20TransactionCollection
from openapi_evm_api.model.erc721_metadata import Erc721Metadata
from openapi_evm_api.model.get_multiple_nfts_dto import GetMultipleNftsDto
from openapi_evm_api.model.get_multiple_token_prices_dto import GetMultipleTokenPricesDto
from openapi_evm_api.model.historical_nft_transfer import HistoricalNftTransfer
from openapi_evm_api.model.include_list import IncludeList
from openapi_evm_api.model.internal_transaction import InternalTransaction
from openapi_evm_api.model.ipfs_file import IpfsFile
from openapi_evm_api.model.ipfs_file_request import IpfsFileRequest
from openapi_evm_api.model.log import Log
from openapi_evm_api.model.log_collection import LogCollection
from openapi_evm_api.model.log_event import LogEvent
from openapi_evm_api.model.log_event_by_address import LogEventByAddress
from openapi_evm_api.model.log_response import LogResponse
from openapi_evm_api.model.log_verbose import LogVerbose
from openapi_evm_api.model.market_data_erc20_token import MarketDataERC20Token
from openapi_evm_api.model.market_data_erc20_tokens_by_price_movers import MarketDataERC20TokensByPriceMovers
from openapi_evm_api.model.market_data_hottest_nft_collection_by_trading_volume import MarketDataHottestNFTCollectionByTradingVolume
from openapi_evm_api.model.market_data_top_nft_collection_by_market_cap import MarketDataTopNFTCollectionByMarketCap
from openapi_evm_api.model.media import Media
from openapi_evm_api.model.media_collection import MediaCollection
from openapi_evm_api.model.media_item import MediaItem
from openapi_evm_api.model.metadata_resync import MetadataResync
from openapi_evm_api.model.native_balance import NativeBalance
from openapi_evm_api.model.native_balances import NativeBalances
from openapi_evm_api.model.native_erc20_price import NativeErc20Price
from openapi_evm_api.model.nft import Nft
from openapi_evm_api.model.nft_collection import NftCollection
from openapi_evm_api.model.nft_collection_stat import NftCollectionStat
from openapi_evm_api.model.nft_collections import NftCollections
from openapi_evm_api.model.nft_contract_metadata import NftContractMetadata
from openapi_evm_api.model.nft_owner import NftOwner
from openapi_evm_api.model.nft_owner_collection import NftOwnerCollection
from openapi_evm_api.model.nft_token_stat import NftTokenStat
from openapi_evm_api.model.nft_transfer import NftTransfer
from openapi_evm_api.model.nft_transfer_collection import NftTransferCollection
from openapi_evm_api.model.nft_wallet_collections import NftWalletCollections
from openapi_evm_api.model.normalized_metadata import NormalizedMetadata
from openapi_evm_api.model.normalized_metadata_attribute import NormalizedMetadataAttribute
from openapi_evm_api.model.reserves_collection import ReservesCollection
from openapi_evm_api.model.reserves_pair import ReservesPair
from openapi_evm_api.model.resolve import Resolve
from openapi_evm_api.model.run_contract_dto import RunContractDto
from openapi_evm_api.model.time_frames import TimeFrames
from openapi_evm_api.model.token_item import TokenItem
from openapi_evm_api.model.token_price_item import TokenPriceItem
from openapi_evm_api.model.trade import Trade
from openapi_evm_api.model.trade_collection import TradeCollection
from openapi_evm_api.model.transaction import Transaction
from openapi_evm_api.model.transaction_collection import TransactionCollection
from openapi_evm_api.model.transaction_collection_verbose import TransactionCollectionVerbose
from openapi_evm_api.model.transaction_timestamp import TransactionTimestamp
from openapi_evm_api.model.unstoppable_domain import UnstoppableDomain
from openapi_evm_api.model.wallet_active_chain import WalletActiveChain
from openapi_evm_api.model.wallet_active_chains import WalletActiveChains
from openapi_evm_api.model.wallet_stat import WalletStat
from openapi_evm_api.model.web3version import Web3version



from .resolve_address import resolve_address
from .resolve_address_to_domain import resolve_address_to_domain
from .resolve_domain import resolve_domain
from .resolve_ens_domain import resolve_ens_domain



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class DiscoveryApiChainsList(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "eth": "ETH",
            "mainnet": "MAINNET",
            "0x1": "X1",
            "matic": "MATIC",
            "0x89": "X89",
            "polygon": "POLYGON",
            "bsc": "BSC",
            "binance": "BINANCE",
            "0x38": "X38",
            "fantom": "FANTOM",
            "ftm": "FTM",
            "0xfa": "XFA",
            "arbitrum": "ARBITRUM",
            "0xa4b1": "XA4B1",
            "optimism": "OPTIMISM",
            "0xa": "XA",
            "pulsechain": "PULSECHAIN",
            "0x171": "X171",
        }
    
    @schemas.classproperty
    def ETH(cls):
        return cls("eth")
    
    @schemas.classproperty
    def MAINNET(cls):
        return cls("mainnet")
    
    @schemas.classproperty
    def X1(cls):
        return cls("0x1")
    
    @schemas.classproperty
    def MATIC(cls):
        return cls("matic")
    
    @schemas.classproperty
    def X89(cls):
        return cls("0x89")
    
    @schemas.classproperty
    def POLYGON(cls):
        return cls("polygon")
    
    @schemas.classproperty
    def BSC(cls):
        return cls("bsc")
    
    @schemas.classproperty
    def BINANCE(cls):
        return cls("binance")
    
    @schemas.classproperty
    def X38(cls):
        return cls("0x38")
    
    @schemas.classproperty
    def FANTOM(cls):
        return cls("fantom")
    
    @schemas.classproperty
    def FTM(cls):
        return cls("ftm")
    
    @schemas.classproperty
    def XFA(cls):
        return cls("0xfa")
    
    @schemas.classproperty
    def ARBITRUM(cls):
        return cls("arbitrum")
    
    @schemas.classproperty
    def XA4B1(cls):
        return cls("0xa4b1")
    
    @schemas.classproperty
    def OPTIMISM(cls):
        return cls("optimism")
    
    @schemas.classproperty
    def XA(cls):
        return cls("0xa")
    
    @schemas.classproperty
    def PULSECHAIN(cls):
        return cls("pulsechain")
    
    @schemas.classproperty
    def X171(cls):
        return cls("0x171")



from .get_hottest_nft_collections_by_trading_volume import get_hottest_nft_collections_by_trading_volume
from .get_top_erc20_tokens_by_market_cap import get_top_erc20_tokens_by_market_cap
from .get_top_erc20_tokens_by_price_movers import get_top_erc20_tokens_by_price_movers
from .get_top_nft_collections_by_market_cap import get_top_nft_collections_by_market_cap



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.discovery_tokens_blue_chip.get import GetBlueChipTokens
from openapi_evm_api.paths.discovery_tokens_buying_pressure.get import GetBuyingPressureTokens
from openapi_evm_api.paths.discovery_token.get import GetDiscoveryToken
from openapi_evm_api.paths.discovery_tokens_experienced_buyers.get import GetExperiencedBuyersTokens
from openapi_evm_api.paths.discovery_tokens_rising_liquidity.get import GetRisingLiquidityTokens
from openapi_evm_api.paths.discovery_tokens_risky_bets.get import GetRiskyBetsTokens
from openapi_evm_api.paths.discovery_tokens_solid_performers.get import GetSolidPerformersTokens


class DefaultApi(
    GetBlueChipTokens,
    GetBuyingPressureTokens,
    GetDiscoveryToken,
    GetExperiencedBuyersTokens,
    GetRisingLiquidityTokens,
    GetRiskyBetsTokens,
    GetSolidPerformersTokens,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class WalletStat(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "nft_transfers",
            "nfts",
            "collections",
            "token_transfers",
            "transactions",
        }
        
        class properties:
            nfts = schemas.StrSchema
            collections = schemas.StrSchema
            
            
            class transactions(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "total",
                    }
                    
                    class properties:
                        total = schemas.StrSchema
                        __annotations__ = {
                            "total": total,
                        }
                
                total: MetaOapg.properties.total
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    total: typing.Union[MetaOapg.properties.total, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'transactions':
                    return super().__new__(
                        cls,
                        *args,
                        total=total,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class nft_transfers(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "total",
                    }
                    
                    class properties:
                        total = schemas.StrSchema
                        __annotations__ = {
                            "total": total,
                        }
                
                total: MetaOapg.properties.total
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    total: typing.Union[MetaOapg.properties.total, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'nft_transfers':
                    return super().__new__(
                        cls,
                        *args,
                        total=total,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class token_transfers(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "total",
                    }
                    
                    class properties:
                        total = schemas.StrSchema
                        __annotations__ = {
                            "total": total,
                        }
                
                total: MetaOapg.properties.total
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    total: typing.Union[MetaOapg.properties.total, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'token_transfers':
                    return super().__new__(
                        cls,
                        *args,
                        total=total,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "nfts": nfts,
                "collections": collections,
                "transactions": transactions,
                "nft_transfers": nft_transfers,
                "token_transfers": token_transfers,
            }

    
    nft_transfers: MetaOapg.properties.nft_transfers
    nfts: MetaOapg.properties.nfts
    collections: MetaOapg.properties.collections
    token_transfers: MetaOapg.properties.token_transfers
    transactions: MetaOapg.properties.transactions
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nfts"]) -> MetaOapg.properties.nfts: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["collections"]) -> MetaOapg.properties.collections: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nft_transfers"]) -> MetaOapg.properties.nft_transfers: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_transfers"]) -> MetaOapg.properties.token_transfers: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["nfts", "collections", "transactions", "nft_transfers", "token_transfers", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nfts"]) -> MetaOapg.properties.nfts: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["collections"]) -> MetaOapg.properties.collections: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nft_transfers"]) -> MetaOapg.properties.nft_transfers: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_transfers"]) -> MetaOapg.properties.token_transfers: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["nfts", "collections", "transactions", "nft_transfers", "token_transfers", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        nft_transfers: typing.Union[MetaOapg.properties.nft_transfers, dict, frozendict.frozendict, ],
        nfts: typing.Union[MetaOapg.properties.nfts, str, ],
        collections: typing.Union[MetaOapg.properties.collections, str, ],
        token_transfers: typing.Union[MetaOapg.properties.token_transfers, dict, frozendict.frozendict, ],
        transactions: typing.Union[MetaOapg.properties.transactions, dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'WalletStat':
        return super().__new__(
            cls,
            *args,
            nft_transfers=nft_transfers,
            nfts=nfts,
            collections=collections,
            token_transfers=token_transfers,
            transactions=transactions,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Erc20TokenBalance(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "symbol",
            "balance",
            "possible_spam",
            "decimals",
            "name",
            "token_address",
        }
        
        class properties:
            token_address = schemas.StrSchema
            name = schemas.StrSchema
            symbol = schemas.StrSchema
            decimals = schemas.IntSchema
            balance = schemas.StrSchema
            possible_spam = schemas.BoolSchema
            logo = schemas.StrSchema
            thumbnail = schemas.StrSchema
            verified_collection = schemas.BoolSchema
            __annotations__ = {
                "token_address": token_address,
                "name": name,
                "symbol": symbol,
                "decimals": decimals,
                "balance": balance,
                "possible_spam": possible_spam,
                "logo": logo,
                "thumbnail": thumbnail,
                "verified_collection": verified_collection,
            }

    
    symbol: MetaOapg.properties.symbol
    balance: MetaOapg.properties.balance
    possible_spam: MetaOapg.properties.possible_spam
    decimals: MetaOapg.properties.decimals
    name: MetaOapg.properties.name
    token_address: MetaOapg.properties.token_address
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["thumbnail"]) -> MetaOapg.properties.thumbnail: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verified_collection"]) -> MetaOapg.properties.verified_collection: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["token_address", "name", "symbol", "decimals", "balance", "possible_spam", "logo", "thumbnail", "verified_collection", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> typing.Union[MetaOapg.properties.logo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["thumbnail"]) -> typing.Union[MetaOapg.properties.thumbnail, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verified_collection"]) -> typing.Union[MetaOapg.properties.verified_collection, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["token_address", "name", "symbol", "decimals", "balance", "possible_spam", "logo", "thumbnail", "verified_collection", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        symbol: typing.Union[MetaOapg.properties.symbol, str, ],
        balance: typing.Union[MetaOapg.properties.balance, str, ],
        possible_spam: typing.Union[MetaOapg.properties.possible_spam, bool, ],
        decimals: typing.Union[MetaOapg.properties.decimals, decimal.Decimal, int, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        token_address: typing.Union[MetaOapg.properties.token_address, str, ],
        logo: typing.Union[MetaOapg.properties.logo, str, schemas.Unset] = schemas.unset,
        thumbnail: typing.Union[MetaOapg.properties.thumbnail, str, schemas.Unset] = schemas.unset,
        verified_collection: typing.Union[MetaOapg.properties.verified_collection, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Erc20TokenBalance':
        return super().__new__(
            cls,
            *args,
            symbol=symbol,
            balance=balance,
            possible_spam=possible_spam,
            decimals=decimals,
            name=name,
            token_address=token_address,
            logo=logo,
            thumbnail=thumbnail,
            verified_collection=verified_collection,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Erc20Metadata(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "symbol",
            "address",
            "possible_spam",
            "decimals",
            "name",
            "created_at",
        }
        
        class properties:
            address = schemas.StrSchema
            name = schemas.StrSchema
            symbol = schemas.StrSchema
            decimals = schemas.StrSchema
            created_at = schemas.StrSchema
            possible_spam = schemas.BoolSchema
            
            
            class address_label(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'address_label':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class logo(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'logo':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class logo_hash(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'logo_hash':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class thumbnail(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'thumbnail':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            block_number = schemas.StrSchema
            validated = schemas.NumberSchema
            __annotations__ = {
                "address": address,
                "name": name,
                "symbol": symbol,
                "decimals": decimals,
                "created_at": created_at,
                "possible_spam": possible_spam,
                "address_label": address_label,
                "logo": logo,
                "logo_hash": logo_hash,
                "thumbnail": thumbnail,
                "block_number": block_number,
                "validated": validated,
            }
    
    symbol: MetaOapg.properties.symbol
    address: MetaOapg.properties.address
    possible_spam: MetaOapg.properties.possible_spam
    decimals: MetaOapg.properties.decimals
    name: MetaOapg.properties.name
    created_at: MetaOapg.properties.created_at
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address_label"]) -> MetaOapg.properties.address_label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logo_hash"]) -> MetaOapg.properties.logo_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["thumbnail"]) -> MetaOapg.properties.thumbnail: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["validated"]) -> MetaOapg.properties.validated: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "name", "symbol", "decimals", "created_at", "possible_spam", "address_label", "logo", "logo_hash", "thumbnail", "block_number", "validated", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address_label"]) -> typing.Union[MetaOapg.properties.address_label, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> typing.Union[MetaOapg.properties.logo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logo_hash"]) -> typing.Union[MetaOapg.properties.logo_hash, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["thumbnail"]) -> typing.Union[MetaOapg.properties.thumbnail, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> typing.Union[MetaOapg.properties.block_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["validated"]) -> typing.Union[MetaOapg.properties.validated, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "name", "symbol", "decimals", "created_at", "possible_spam", "address_label", "logo", "logo_hash", "thumbnail", "block_number", "validated", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        symbol: typing.Union[MetaOapg.properties.symbol, str, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        possible_spam: typing.Union[MetaOapg.properties.possible_spam, bool, ],
        decimals: typing.Union[MetaOapg.properties.decimals, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        created_at: typing.Union[MetaOapg.properties.created_at, str, ],
        address_label: typing.Union[MetaOapg.properties.address_label, None, str, schemas.Unset] = schemas.unset,
        logo: typing.Union[MetaOapg.properties.logo, None, str, schemas.Unset] = schemas.unset,
        logo_hash: typing.Union[MetaOapg.properties.logo_hash, None, str, schemas.Unset] = schemas.unset,
        thumbnail: typing.Union[MetaOapg.properties.thumbnail, None, str, schemas.Unset] = schemas.unset,
        block_number: typing.Union[MetaOapg.properties.block_number, str, schemas.Unset] = schemas.unset,
        validated: typing.Union[MetaOapg.properties.validated, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Erc20Metadata':
        return super().__new__(
            cls,
            *args,
            symbol=symbol,
            address=address,
            possible_spam=possible_spam,
            decimals=decimals,
            name=name,
            created_at=created_at,
            address_label=address_label,
            logo=logo,
            logo_hash=logo_hash,
            thumbnail=thumbnail,
            block_number=block_number,
            validated=validated,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class DiscoveryTokenLinks(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "youtube",
            "github",
            "website",
            "facebook",
            "telegram",
            "instagram",
            "linkedin",
            "medium",
            "bitbucket",
            "twitter",
            "discord",
            "tiktok",
            "reddit",
        }
        
        class properties:
            bitbucket = schemas.StrSchema
            discord = schemas.StrSchema
            facebook = schemas.StrSchema
            github = schemas.StrSchema
            instagram = schemas.StrSchema
            linkedin = schemas.StrSchema
            medium = schemas.StrSchema
            reddit = schemas.StrSchema
            telegram = schemas.StrSchema
            tiktok = schemas.StrSchema
            twitter = schemas.StrSchema
            website = schemas.StrSchema
            youtube = schemas.StrSchema
            __annotations__ = {
                "bitbucket": bitbucket,
                "discord": discord,
                "facebook": facebook,
                "github": github,
                "instagram": instagram,
                "linkedin": linkedin,
                "medium": medium,
                "reddit": reddit,
                "telegram": telegram,
                "tiktok": tiktok,
                "twitter": twitter,
                "website": website,
                "youtube": youtube,
            }
    
    youtube: MetaOapg.properties.youtube
    github: MetaOapg.properties.github
    website: MetaOapg.properties.website
    facebook: MetaOapg.properties.facebook
    telegram: MetaOapg.properties.telegram
    instagram: MetaOapg.properties.instagram
    linkedin: MetaOapg.properties.linkedin
    medium: MetaOapg.properties.medium
    bitbucket: MetaOapg.properties.bitbucket
    twitter: MetaOapg.properties.twitter
    discord: MetaOapg.properties.discord
    tiktok: MetaOapg.properties.tiktok
    reddit: MetaOapg.properties.reddit
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bitbucket"]) -> MetaOapg.properties.bitbucket: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["discord"]) -> MetaOapg.properties.discord: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["facebook"]) -> MetaOapg.properties.facebook: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["github"]) -> MetaOapg.properties.github: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["instagram"]) -> MetaOapg.properties.instagram: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["linkedin"]) -> MetaOapg.properties.linkedin: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["medium"]) -> MetaOapg.properties.medium: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reddit"]) -> MetaOapg.properties.reddit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["telegram"]) -> MetaOapg.properties.telegram: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tiktok"]) -> MetaOapg.properties.tiktok: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["twitter"]) -> MetaOapg.properties.twitter: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["website"]) -> MetaOapg.properties.website: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["youtube"]) -> MetaOapg.properties.youtube: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["bitbucket", "discord", "facebook", "github", "instagram", "linkedin", "medium", "reddit", "telegram", "tiktok", "twitter", "website", "youtube", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bitbucket"]) -> MetaOapg.properties.bitbucket: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["discord"]) -> MetaOapg.properties.discord: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["facebook"]) -> MetaOapg.properties.facebook: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["github"]) -> MetaOapg.properties.github: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["instagram"]) -> MetaOapg.properties.instagram: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["linkedin"]) -> MetaOapg.properties.linkedin: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["medium"]) -> MetaOapg.properties.medium: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reddit"]) -> MetaOapg.properties.reddit: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["telegram"]) -> MetaOapg.properties.telegram: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tiktok"]) -> MetaOapg.properties.tiktok: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["twitter"]) -> MetaOapg.properties.twitter: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["website"]) -> MetaOapg.properties.website: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["youtube"]) -> MetaOapg.properties.youtube: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["bitbucket", "discord", "facebook", "github", "instagram", "linkedin", "medium", "reddit", "telegram", "tiktok", "twitter", "website", "youtube", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        youtube: typing.Union[MetaOapg.properties.youtube, str, ],
        github: typing.Union[MetaOapg.properties.github, str, ],
        website: typing.Union[MetaOapg.properties.website, str, ],
        facebook: typing.Union[MetaOapg.properties.facebook, str, ],
        telegram: typing.Union[MetaOapg.properties.telegram, str, ],
        instagram: typing.Union[MetaOapg.properties.instagram, str, ],
        linkedin: typing.Union[MetaOapg.properties.linkedin, str, ],
        medium: typing.Union[MetaOapg.properties.medium, str, ],
        bitbucket: typing.Union[MetaOapg.properties.bitbucket, str, ],
        twitter: typing.Union[MetaOapg.properties.twitter, str, ],
        discord: typing.Union[MetaOapg.properties.discord, str, ],
        tiktok: typing.Union[MetaOapg.properties.tiktok, str, ],
        reddit: typing.Union[MetaOapg.properties.reddit, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'DiscoveryTokenLinks':
        return super().__new__(
            cls,
            *args,
            youtube=youtube,
            github=github,
            website=website,
            facebook=facebook,
            telegram=telegram,
            instagram=instagram,
            linkedin=linkedin,
            medium=medium,
            bitbucket=bitbucket,
            twitter=twitter,
            discord=discord,
            tiktok=tiktok,
            reddit=reddit,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class NftTransfer(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "contract_type",
            "possible_spam",
            "token_id",
            "block_timestamp",
            "block_hash",
            "block_number",
            "to_address",
            "token_address",
            "log_index",
            "transaction_hash",
        }
        
        class properties:
            token_address = schemas.StrSchema
            token_id = schemas.StrSchema
            to_address = schemas.StrSchema
            contract_type = schemas.StrSchema
            block_number = schemas.StrSchema
            block_timestamp = schemas.StrSchema
            block_hash = schemas.StrSchema
            transaction_hash = schemas.StrSchema
            log_index = schemas.IntSchema
            possible_spam = schemas.BoolSchema
            from_address = schemas.StrSchema
            
            
            class from_address_label(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'from_address_label':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class to_address_label(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'to_address_label':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            value = schemas.StrSchema
            amount = schemas.StrSchema
            transaction_type = schemas.StrSchema
            transaction_index = schemas.IntSchema
            operator = schemas.StrSchema
            verified_collection = schemas.BoolSchema
            __annotations__ = {
                "token_address": token_address,
                "token_id": token_id,
                "to_address": to_address,
                "contract_type": contract_type,
                "block_number": block_number,
                "block_timestamp": block_timestamp,
                "block_hash": block_hash,
                "transaction_hash": transaction_hash,
                "log_index": log_index,
                "possible_spam": possible_spam,
                "from_address": from_address,
                "from_address_label": from_address_label,
                "to_address_label": to_address_label,
                "value": value,
                "amount": amount,
                "transaction_type": transaction_type,
                "transaction_index": transaction_index,
                "operator": operator,
                "verified_collection": verified_collection,
            }

    
    contract_type: MetaOapg.properties.contract_type
    possible_spam: MetaOapg.properties.possible_spam
    token_id: MetaOapg.properties.token_id
    block_timestamp: MetaOapg.properties.block_timestamp
    block_hash: MetaOapg.properties.block_hash
    block_number: MetaOapg.properties.block_number
    to_address: MetaOapg.properties.to_address
    token_address: MetaOapg.properties.token_address
    log_index: MetaOapg.properties.log_index
    transaction_hash: MetaOapg.properties.transaction_hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_id"]) -> MetaOapg.properties.token_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to_address"]) -> MetaOapg.properties.to_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["contract_type"]) -> MetaOapg.properties.contract_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["log_index"]) -> MetaOapg.properties.log_index: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from_address"]) -> MetaOapg.properties.from_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from_address_label"]) -> MetaOapg.properties.from_address_label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to_address_label"]) -> MetaOapg.properties.to_address_label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_type"]) -> MetaOapg.properties.transaction_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_index"]) -> MetaOapg.properties.transaction_index: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operator"]) -> MetaOapg.properties.operator: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verified_collection"]) -> MetaOapg.properties.verified_collection: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["token_address", "token_id", "to_address", "contract_type", "block_number", "block_timestamp", "block_hash", "transaction_hash", "log_index", "possible_spam", "from_address", "from_address_label", "to_address_label", "value", "amount", "transaction_type", "transaction_index", "operator", "verified_collection", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_id"]) -> MetaOapg.properties.token_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to_address"]) -> MetaOapg.properties.to_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["contract_type"]) -> MetaOapg.properties.contract_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["log_index"]) -> MetaOapg.properties.log_index: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from_address"]) -> typing.Union[MetaOapg.properties.from_address, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from_address_label"]) -> typing.Union[MetaOapg.properties.from_address_label, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to_address_label"]) -> typing.Union[MetaOapg.properties.to_address_label, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union[MetaOapg.properties.amount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_type"]) -> typing.Union[MetaOapg.properties.transaction_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_index"]) -> typing.Union[MetaOapg.properties.transaction_index, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operator"]) -> typing.Union[MetaOapg.properties.operator, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verified_collection"]) -> typing.Union[MetaOapg.properties.verified_collection, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["token_address", "token_id", "to_address", "contract_type", "block_number", "block_timestamp", "block_hash", "transaction_hash", "log_index", "possible_spam", "from_address", "from_address_label", "to_address_label", "value", "amount", "transaction_type", "transaction_index", "operator", "verified_collection", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        contract_type: typing.Union[MetaOapg.properties.contract_type, str, ],
        possible_spam: typing.Union[MetaOapg.properties.possible_spam, bool, ],
        token_id: typing.Union[MetaOapg.properties.token_id, str, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        to_address: typing.Union[MetaOapg.properties.to_address, str, ],
        token_address: typing.Union[MetaOapg.properties.token_address, str, ],
        log_index: typing.Union[MetaOapg.properties.log_index, decimal.Decimal, int, ],
        transaction_hash: typing.Union[MetaOapg.properties.transaction_hash, str, ],
        from_address: typing.Union[MetaOapg.properties.from_address, str, schemas.Unset] = schemas.unset,
        from_address_label: typing.Union[MetaOapg.properties.from_address_label, None, str, schemas.Unset] = schemas.unset,
        to_address_label: typing.Union[MetaOapg.properties.to_address_label, None, str, schemas.Unset] = schemas.unset,
        value: typing.Union[MetaOapg.properties.value, str, schemas.Unset] = schemas.unset,
        amount: typing.Union[MetaOapg.properties.amount, str, schemas.Unset] = schemas.unset,
        transaction_type: typing.Union[MetaOapg.properties.transaction_type, str, schemas.Unset] = schemas.unset,
        transaction_index: typing.Union[MetaOapg.properties.transaction_index, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        operator: typing.Union[MetaOapg.properties.operator, str, schemas.Unset] = schemas.unset,
        verified_collection: typing.Union[MetaOapg.properties.verified_collection, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NftTransfer':
        return super().__new__(
            cls,
            *args,
            contract_type=contract_type,
            possible_spam=possible_spam,
            token_id=token_id,
            block_timestamp=block_timestamp,
            block_hash=block_hash,
            block_number=block_number,
            to_address=to_address,
            token_address=token_address,
            log_index=log_index,
            transaction_hash=transaction_hash,
            from_address=from_address,
            from_address_label=from_address_label,
            to_address_label=to_address_label,
            value=value,
            amount=amount,
            transaction_type=transaction_type,
            transaction_index=transaction_index,
            operator=operator,
            verified_collection=verified_collection,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class NftTokenStat(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "transfers",
            "owners",
        }
        
        class properties:
            
            
            class owners(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "current",
                    }
                    
                    class properties:
                        current = schemas.StrSchema
                        __annotations__ = {
                            "current": current,
                        }
                
                current: MetaOapg.properties.current
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["current"]) -> MetaOapg.properties.current: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["current", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["current"]) -> MetaOapg.properties.current: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["current", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    current: typing.Union[MetaOapg.properties.current, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'owners':
                    return super().__new__(
                        cls,
                        *args,
                        current=current,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class transfers(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "total",
                    }
                    
                    class properties:
                        total = schemas.StrSchema
                        __annotations__ = {
                            "total": total,
                        }
                
                total: MetaOapg.properties.total
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    total: typing.Union[MetaOapg.properties.total, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'transfers':
                    return super().__new__(
                        cls,
                        *args,
                        total=total,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "owners": owners,
                "transfers": transfers,
            }

    
    transfers: MetaOapg.properties.transfers
    owners: MetaOapg.properties.owners
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["owners"]) -> MetaOapg.properties.owners: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transfers"]) -> MetaOapg.properties.transfers: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["owners", "transfers", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["owners"]) -> MetaOapg.properties.owners: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transfers"]) -> MetaOapg.properties.transfers: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["owners", "transfers", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        transfers: typing.Union[MetaOapg.properties.transfers, dict, frozendict.frozendict, ],
        owners: typing.Union[MetaOapg.properties.owners, dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NftTokenStat':
        return super().__new__(
            cls,
            *args,
            transfers=transfers,
            owners=owners,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class TimeFrames(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "1d",
            "1w",
            "1h",
            "1M",
        }
        
        class properties:
            
            
            class _1h(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> '_1h':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class _1d(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> '_1d':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class _1w(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> '_1w':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class _1_m(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> '_1_m':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "1h": _1h,
                "1d": _1d,
                "1w": _1w,
                "1M": _1_m,
            }
    
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["1h"]) -> MetaOapg.properties._1h: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["1d"]) -> MetaOapg.properties._1d: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["1w"]) -> MetaOapg.properties._1w: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["1M"]) -> MetaOapg.properties._1_m: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["1h", "1d", "1w", "1M", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["1h"]) -> MetaOapg.properties._1h: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["1d"]) -> MetaOapg.properties._1d: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["1w"]) -> MetaOapg.properties._1w: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["1M"]) -> MetaOapg.properties._1_m: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["1h", "1d", "1w", "1M", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TimeFrames':
        return super().__new__(
            cls,
            *args,
            _configuration=_configuration,
            **kwargs,
        )



import json
import typing
import typing_extensions
from .api_instance import get_api_instance
from openapi_aptos_api.paths.transactions.post import SchemaForRequestBodyApplicationJson

RequestNetworkQueryParams = typing_extensions.TypedDict("RequestNetworkQueryParams", {
    "network": typing.Literal["mainnet","testnet",]}, total=False)





def submit_transaction(api_key: str, body: SchemaForRequestBodyApplicationJson):
    api_instance = get_api_instance(api_key)
    api_response = api_instance.submit_transaction(
        body=body,
        accept_content_types=(
            'application/json; charset=utf-8',
        ),
        skip_deserialization=True
    )

    return json.loads(api_response.response.data)



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class WalletActiveChain(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "chain",
            "chain_id",
        }
        
        class properties:
            chain = schemas.StrSchema
            chain_id = schemas.StrSchema
        
            @staticmethod
            def first_transaction() -> typing.Type['TransactionTimestamp']:
                return TransactionTimestamp
        
            @staticmethod
            def last_transaction() -> typing.Type['TransactionTimestamp']:
                return TransactionTimestamp
            __annotations__ = {
                "chain": chain,
                "chain_id": chain_id,
                "first_transaction": first_transaction,
                "last_transaction": last_transaction,
            }

    
    chain: MetaOapg.properties.chain
    chain_id: MetaOapg.properties.chain_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chain"]) -> MetaOapg.properties.chain: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["first_transaction"]) -> 'TransactionTimestamp': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_transaction"]) -> 'TransactionTimestamp': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["chain", "chain_id", "first_transaction", "last_transaction", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chain"]) -> MetaOapg.properties.chain: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["first_transaction"]) -> typing.Union['TransactionTimestamp', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_transaction"]) -> typing.Union['TransactionTimestamp', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["chain", "chain_id", "first_transaction", "last_transaction", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        chain: typing.Union[MetaOapg.properties.chain, str, ],
        chain_id: typing.Union[MetaOapg.properties.chain_id, str, ],
        first_transaction: typing.Union['TransactionTimestamp', schemas.Unset] = schemas.unset,
        last_transaction: typing.Union['TransactionTimestamp', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'WalletActiveChain':
        return super().__new__(
            cls,
            *args,
            chain=chain,
            chain_id=chain_id,
            first_transaction=first_transaction,
            last_transaction=last_transaction,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.transaction_timestamp import TransactionTimestamp
